@@ -6,5 +6,5 @@ from .views import HelloSignWebhookEventHandler
 
 
 urlpatterns = patterns('',
-    url(r'^hellosign/event/$', csrf_exempt(HelloSignWebhookEventHandler.as_view()), name='hellosign_webhook_event'),
+    url(r'^event/$', csrf_exempt(HelloSignWebhookEventHandler.as_view()), name='hellosign_webhook_event'),
 )
